#!/bin/sh
. ./IDMETA
P=$NAME-$VERSION
rm -fr debian/tmp debian/cf-xulrunner[0-9][0-9] debian/cf-xulrunner[0-9][0-9]-dev
rm -f debian/*.log debian/files debian/*.substvars
rm -fr $P
mkdir $P
git log >$P/ChangeLog
cp IDMETA mkdist.sh mozconfig* cf-xulrunner.spec *.patch $P
tar zcvf $NAME-$VERSION.tar.gz $P
rm -fr $P
